==> malli-0.7.4.jar: malli/dev.clj <==
(ns malli.dev
  (:require [malli.core :as m]
            [malli.instrument :as mi]
            [malli.clj-kondo :as clj-kondo]))

(defn stop!
  "Stops instrumentation for all functions vars and removes clj-kondo type annotations."
  []
  (remove-watch @#'m/-function-schemas* ::watch)
  (mi/unstrument!)
  (clj-kondo/save! {})
  (println "stopped instrumentation"))

(defn start!
  "Collects defn schemas from all loaded namespaces and starts instrumentation for
   a filtered set of function Vars (e.g. `defn`s). See [[malli.core/-instrument]]
   for possible options. Re-instruments if the function schemas change. Also emits
   clj-kondo type annotations."
  ([] (start! nil))
  ([options]
   (with-out-str (stop!))
   (mi/collect! {:ns (all-ns)})
   (let [watch (fn [_ _ old new]
                 (mi/instrument! (assoc options :data (->> (for [[n d] new
                                                                 :let [no (get old n)]
                                                                 [s d] d
                                                                 :when (not= d (get no s))]
                                                             [[n s] d])
                                                           (into {})
                                                           (reduce-kv assoc-in {}))))
                 (clj-kondo/emit!))]
     (add-watch @#'m/-function-schemas* ::watch watch))
   (mi/instrument! options)
   (clj-kondo/emit!)
   (println "started instrumentation")))

==> malli-0.8.1.jar: malli/dev.clj <==
(ns malli.dev
  (:require [malli.core :as m]
            [malli.instrument :as mi]
            [malli.dev.pretty :as pretty]
            [malli.clj-kondo :as clj-kondo]))

(defn stop!
  "Stops instrumentation for all functions vars and removes clj-kondo type annotations."
  []
  (remove-watch @#'m/-function-schemas* ::watch)
  (mi/unstrument!)
  (clj-kondo/save! {})
  (println "stopped instrumentation"))

(defn start!
  "Collects defn schemas from all loaded namespaces and starts instrumentation for
   a filtered set of function Vars (e.g. `defn`s). See [[malli.core/-instrument]]
   for possible options. Re-instruments if the function schemas change. Also emits
   clj-kondo type annotations."
  ([] (start! {:report (pretty/reporter)}))
  ([options]
   (with-out-str (stop!))
   (mi/collect! {:ns (all-ns)})
   (let [watch (fn [_ _ old new]
                 (mi/instrument! (assoc options :data (->> (for [[n d] (:clj new)
                                                                 :let [no (get-in old [:clj n])]
                                                                 [s d] d
                                                                 :when (not= d (get no s))]
                                                             [[n s] d])
                                                           (into {})
                                                           (reduce-kv assoc-in {}))))
                 (clj-kondo/emit!))]
     (add-watch @#'m/-function-schemas* ::watch watch))
   (mi/instrument! options)
   (clj-kondo/emit!)
   (println "started instrumentation")))
